[![Build Status](https://travis-ci.org/Terralego/django-datastore.svg?branch=master)](https://travis-ci.org/Terralego/django-datastore)
[![codecov](https://codecov.io/gh/Terralego/django-datastore/branch/master/graph/badge.svg)](https://codecov.io/gh/Terralego/django-datastore)
[![PyPi version](https://pypip.in/v/django-datastore/badge.png)](https://pypi.org/project/django-datastore/)

# Django Datastore

Django application to either :
  - store unstructured data in JSON format with permission handling
  - store files for models through a generic foreign key
  
All of that can be handled with a REST API thanks to Django REST Framework.

